@@ -13,15 +13,20 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this library.  If not, see <http://www.gnu.org/licenses/>.
 
+require "json"
+
 module Milter::Manager
   class ChildContext
     include Milter::MacroNameNormalizer
     include Milter::MacroPredicates
 
+    attr_reader :mail_transaction_shelf
+
     def initialize(child, children, client_context)
       @child = child
       @children = children
       @client_context = client_context
+      @mail_transaction_shelf = Milter::Client::MailTransactionShelf.new(client_context)
     end
 
     def name
