@@ -1,5 +1,10 @@
-require 'test/unit/color-scheme'
-require 'optparse'
+require "English"
+
+require "test/unit/color-scheme"
+require "test/unit/priority"
+require "test/unit/attribute-matcher"
+require "test/unit/testcase"
+require "optparse"
 
 module Test
   module Unit
@@ -48,44 +53,58 @@ module Test
         def prepare(hook=Proc.new)
           PREPARE_HOOKS << hook
         end
-      end
 
-      def self.run(force_standalone=false, default_dir=nil, argv=ARGV, &block)
-        r = new(force_standalone || standalone?, &block)
-        r.base = default_dir
-        r.prepare
-        r.process_args(argv)
-        r.run
-      end
+        def run(force_standalone=false, default_dir=nil, argv=ARGV, &block)
+          r = new(force_standalone || standalone?, &block)
+          r.base = default_dir
+          r.prepare
+          r.process_args(argv)
+          r.run
+        end
 
-      def self.standalone?
-        return false unless("-e" == $0)
-        ObjectSpace.each_object(Class) do |klass|
-          return false if(klass < TestCase)
+        def standalone?
+          return false unless("-e" == $0)
+          ObjectSpace.each_object(Class) do |klass|
+            return false if(klass < TestCase)
+          end
+          true
+        end
+
+        @@need_auto_run = true
+        def need_auto_run?
+          @@need_auto_run
+        end
+
+        def need_auto_run=(need)
+          @@need_auto_run = need
         end
-        true
       end
 
       register_collector(:descendant) do |auto_runner|
-        require 'test/unit/collector/descendant'
+        require "test/unit/collector/descendant"
         collector = Collector::Descendant.new
         collector.filter = auto_runner.filters
-        collector.collect($0.sub(/\.rb\Z/, ''))
+        collector.collect($0.sub(/\.rb\Z/, ""))
       end
 
       register_collector(:load) do |auto_runner|
-        require 'test/unit/collector/load'
+        require "test/unit/collector/load"
         collector = Collector::Load.new
-        collector.patterns.concat(auto_runner.pattern) if auto_runner.pattern
-        collector.excludes.concat(auto_runner.exclude) if auto_runner.exclude
+        unless auto_runner.pattern.empty?
+          collector.patterns.replace(auto_runner.pattern)
+        end
+        unless auto_runner.exclude.empty?
+          collector.excludes.replace(auto_runner.exclude)
+        end
         collector.base = auto_runner.base
+        collector.default_test_paths = auto_runner.default_test_paths
         collector.filter = auto_runner.filters
         collector.collect(*auto_runner.to_run)
       end
 
       # JUST TEST!
       # register_collector(:xml) do |auto_runner|
-      #   require 'test/unit/collector/xml'
+      #   require "test/unit/collector/xml"
       #   collector = Collector::XML.new
       #   collector.filter = auto_runner.filters
       #   collector.collect(auto_runner.to_run[0])
@@ -93,41 +112,49 @@ module Test
 
       # deprecated
       register_collector(:object_space) do |auto_runner|
-        require 'test/unit/collector/objectspace'
+        require "test/unit/collector/objectspace"
         c = Collector::ObjectSpace.new
         c.filter = auto_runner.filters
-        c.collect($0.sub(/\.rb\Z/, ''))
+        c.collect($0.sub(/\.rb\Z/, ""))
       end
 
       # deprecated
       register_collector(:dir) do |auto_runner|
-        require 'test/unit/collector/dir'
+        require "test/unit/collector/dir"
         c = Collector::Dir.new
         c.filter = auto_runner.filters
-        c.pattern.concat(auto_runner.pattern) if auto_runner.pattern
-        c.exclude.concat(auto_runner.exclude) if auto_runner.exclude
+        unless auto_runner.pattern.empty?
+          c.pattern.replace(auto_runner.pattern)
+        end
+        unless auto_runner.exclude.empty?
+          c.exclude.replace(auto_runner.exclude)
+        end
         c.base = auto_runner.base
         $:.push(auto_runner.base) if auto_runner.base
-        c.collect(*(auto_runner.to_run.empty? ? ['.'] : auto_runner.to_run))
+        c.collect(*(auto_runner.to_run.empty? ? ["."] : auto_runner.to_run))
       end
 
       attr_reader :suite, :runner_options
-      attr_accessor :filters, :to_run, :pattern, :exclude, :base, :workdir
+      attr_accessor :filters, :to_run
+      attr_accessor :default_test_paths
+      attr_accessor :pattern, :exclude, :base, :workdir
       attr_accessor :color_scheme, :listeners
+      attr_writer :stop_on_failuere
       attr_writer :runner, :collector
 
       def initialize(standalone)
-        Unit.run = true
         @standalone = standalone
         @runner = default_runner
         @collector = default_collector
         @filters = []
         @to_run = []
+        @default_test_paths = []
         @color_scheme = ColorScheme.default
         @runner_options = {}
         @default_arguments = []
         @workdir = nil
         @listeners = []
+        @stop_on_failure = false
         config_file = "test-unit.yml"
         if File.exist?(config_file)
           load_config(config_file)
@@ -137,16 +164,20 @@ module Test
         yield(self) if block_given?
       end
 
+      def stop_on_failure?
+        @stop_on_failure
+      end
+
       def prepare
         PREPARE_HOOKS.each do |handler|
           handler.call(self)
         end
       end
 
-      def process_args(args = ARGV)
+      def process_args(args=ARGV)
         begin
           args.unshift(*@default_arguments)
-          options.order!(args) {|arg| @to_run << arg}
+          options.order!(args) {|arg| add_test_path(arg)}
         rescue OptionParser::ParseError => e
           puts e
           puts options
@@ -160,63 +191,69 @@ module Test
           o.banner = "Test::Unit automatic runner."
           o.banner << "\nUsage: #{$0} [options] [-- untouched arguments]"
 
-          o.on
-          o.on('-r', '--runner=RUNNER', RUNNERS,
+          o.on("-r", "--runner=RUNNER", RUNNERS,
                "Use the given RUNNER.",
                "(" + keyword_display(RUNNERS) + ")") do |r|
             @runner = r
           end
 
-          o.on
-          o.on('--collector=COLLECTOR', COLLECTORS,
+          o.on("--collector=COLLECTOR", COLLECTORS,
                "Use the given COLLECTOR.",
                "(" + keyword_display(COLLECTORS) + ")") do |collector|
             @collector = collector
           end
 
           if (@standalone)
-            o.on('-b', '--basedir=DIR', "Base directory of test suites.") do |b|
+            o.on("-b", "--basedir=DIR", "Base directory of test suites.") do |b|
               @base = b
             end
 
-            o.on('-w', '--workdir=DIR', "Working directory to run tests.") do |w|
+            o.on("-w", "--workdir=DIR", "Working directory to run tests.") do |w|
               @workdir = w
             end
 
-            o.on('-a', '--add=TORUN', Array,
+            o.on("--default-test-path=PATH",
+                 "Add PATH to the default test paths.",
+                 "The PATH is used when user doesn't specify any test path.",
+                 "You can specify this option multiple times.") do |path|
+              @default_test_paths << path
+            end
+
+            o.on("-a", "--add=TORUN", Array,
                  "Add TORUN to the list of things to run;",
-                 "can be a file or a directory.") do |a|
-              @to_run.concat(a)
+                 "can be a file or a directory.") do |paths|
+              paths.each do |path|
+                add_test_path(path)
+              end
             end
 
             @pattern = []
-            o.on('-p', '--pattern=PATTERN', Regexp,
+            o.on("-p", "--pattern=PATTERN", Regexp,
                  "Match files to collect against PATTERN.") do |e|
               @pattern << e
             end
 
             @exclude = []
-            o.on('-x', '--exclude=PATTERN', Regexp,
+            o.on("-x", "--exclude=PATTERN", Regexp,
                  "Ignore files to collect against PATTERN.") do |e|
               @exclude << e
             end
           end
 
-          o.on('-n', '--name=NAME', String,
+          o.on("-n", "--name=NAME", String,
                "Runs tests matching NAME.",
-               "(patterns may be used).") do |n|
-            n = (%r{\A/(.*)/\Z} =~ n ? Regexp.new($1) : n)
-            case n
-            when Regexp
-              @filters << proc{|t| n =~ t.method_name ? true : false}
-            else
-              @filters << proc{|t| n == t.method_name}
+               "Use '/PATTERN/' for NAME to use regular expression.") do |name|
+            name = (%r{\A/(.*)/\Z} =~ name ? Regexp.new($1) : name)
+            @filters << lambda do |test|
+              return true if name === test.method_name
+              return true if name === test.local_name
+              false
             end
           end
 
-          o.on('--ignore-name=NAME', String,
+          o.on("--ignore-name=NAME", String,
                "Ignores tests matching NAME.",
-               "(patterns may be used).") do |n|
+               "Use '/PATTERN/' for NAME to use regular expression.") do |n|
             n = (%r{\A/(.*)/\Z} =~ n ? Regexp.new($1) : n)
             case n
             when Regexp
@@ -226,27 +263,47 @@ module Test
             end
           end
 
-          o.on('-t', '--testcase=TESTCASE', String,
+          o.on("-t", "--testcase=TESTCASE", String,
                "Runs tests in TestCases matching TESTCASE.",
-               "(patterns may be used).") do |n|
+               "Use '/PATTERN/' for TESTCASE to use regular expression.") do |n|
             n = (%r{\A/(.*)/\Z} =~ n ? Regexp.new($1) : n)
-            case n
-            when Regexp
-              @filters << proc{|t| n =~ t.class.name ? true : false}
-            else
-              @filters << proc{|t| n == t.class.name}
+            @filters << lambda do |test|
+              match_test_case_name(test, n)
             end
           end
 
-          o.on('--ignore-testcase=TESTCASE', String,
+          o.on("--ignore-testcase=TESTCASE", String,
                "Ignores tests in TestCases matching TESTCASE.",
-               "(patterns may be used).") do |n|
+               "Use '/PATTERN/' for TESTCASE to use regular expression.") do |n|
             n = (%r{\A/(.*)/\Z} =~ n ? Regexp.new($1) : n)
-            case n
-            when Regexp
-              @filters << proc {|t| n =~ t.class.name ? false : true}
+            @filters << lambda do |test|
+              not match_test_case_name(test, n)
+            end
+          end
+
+          o.on("--location=LOCATION", String,
+               "Runs tests that defined in LOCATION.",
+               "LOCATION is one of PATH:LINE, PATH or LINE") do |location|
+            if /\A\d+\z/ =~ location
+              path = nil
+              line = location.to_i
             else
-              @filters << proc {|t| n != t.class.name}
+              path, line, = location.split(/:(\d+)/, 2)
+              line = line.to_i unless line.nil?
+            end
+            add_location_filter(path, line)
+          end
+
+          o.on("--attribute=EXPRESSION", String,
+               "Runs tests that matches EXPRESSION.",
+               "EXPRESSION is evaluated as Ruby's expression.",
+               "Test attribute name can be used with no receiver in EXPRESSION.",
+               "EXPRESSION examples:",
+               "  !slow",
+               "  tag == 'important' and !slow") do |expression|
+            @filters << lambda do |test|
+              matcher = AttributeMatcher.new(test)
+              matcher.match?(expression)
             end
           end
 
@@ -275,7 +332,7 @@ module Test
             Priority.default = priority
           end
 
-          o.on('-I', "--load-path=DIR[#{File::PATH_SEPARATOR}DIR...]",
+          o.on("-I", "--load-path=DIR[#{File::PATH_SEPARATOR}DIR...]",
                "Appends directory list to $LOAD_PATH.") do |dirs|
             $LOAD_PATH.concat(dirs.split(File::PATH_SEPARATOR))
           end
@@ -298,27 +355,42 @@ module Test
             TestCase.test_order = order
           end
 
+          assertion_message_class = Test::Unit::Assertions::AssertionMessage
+          o.on("--max-diff-target-string-size=SIZE", Integer,
+               "Shows diff if both expected result string size and " +
+               "actual result string size are " +
+               "less than or equal SIZE in bytes.",
+               "(#{assertion_message_class.max_diff_target_string_size})") do |size|
+            assertion_message_class.max_diff_target_string_size = size
+          end
+
+          o.on("--[no-]stop-on-failure",
+               "Stops immediately on the first non success test",
+               "(#{@stop_on_failure})") do |boolean|
+            @stop_on_failure = boolean
+          end
+
           ADDITIONAL_OPTIONS.each do |option_builder|
             option_builder.call(self, o)
           end
 
-          o.on('--',
+          o.on("--",
                "Stop processing options so that the",
                "remaining options will be passed to the",
                "test."){o.terminate}
 
-          o.on('-h', '--help', 'Display this help.'){puts o; exit}
+          o.on("-h", "--help", "Display this help."){puts o; exit}
 
           o.on_tail
-          o.on_tail('Deprecated options:')
+          o.on_tail("Deprecated options:")
 
-          o.on_tail('--console', 'Console runner (use --runner).') do
+          o.on_tail("--console", "Console runner (use --runner).") do
             warn("Deprecated option (--console).")
             @runner = self.class.runner(:console)
           end
 
           if RUNNERS[:fox]
-            o.on_tail('--fox', 'Fox runner (use --runner).') do
+            o.on_tail("--fox", "Fox runner (use --runner).") do
               warn("Deprecated option (--fox).")
               @runner = self.class.runner(:fox)
             end
@@ -347,19 +419,25 @@ module Test
       end
 
       def run
+        self.class.need_auto_run = false
         suite = @collector[self]
         return false if suite.nil?
+        return true if suite.empty?
         runner = @runner[self]
         return false if runner.nil?
         @runner_options[:color_scheme] ||= @color_scheme
         @runner_options[:listeners] ||= []
         @runner_options[:listeners].concat(@listeners)
-        Dir.chdir(@workdir) if @workdir
-        runner.run(suite, @runner_options).passed?
+        if @stop_on_failure
+          @runner_options[:listeners] << StopOnFailureListener.new
+        end
+        change_work_directory do
+          runner.run(suite, @runner_options).passed?
+        end
       end
 
       def load_config(file)
-        require 'yaml'
+        require "yaml"
         config = YAML.load(File.read(file))
         runner_name = config["runner"]
         @runner = self.class.runner(runner_name) || @runner
@@ -405,11 +483,51 @@ module Test
         file = global_config_file
         load_config(file) if file and File.exist?(file)
       end
+
+      def change_work_directory(&block)
+        if @workdir
+          Dir.chdir(@workdir, &block)
+        else
+          yield
+        end
+      end
+
+      def match_test_case_name(test, pattern)
+        test.class.ancestors.each do |test_class|
+          break if test_class == TestCase
+          return true if pattern === test_class.name
+        end
+        false
+      end
+
+      def add_test_path(path)
+        if /:(\d+)\z/ =~ path
+          line = $1.to_i
+          path = $PREMATCH
+          add_location_filter(path, line)
+        end
+        @to_run << path
+      end
+
+      def add_location_filter(path, line)
+        @filters << lambda do |test|
+          test.class.test_defined?(:path => path,
+                                   :line => line,
+                                   :method_name => test.method_name)
+        end
+      end
+
+      class StopOnFailureListener
+        def attach_to_mediator(mediator)
+          mediator.add_listener(TestResult::FINISHED) do |result|
+            result.stop unless result.passed?
+          end
+        end
+      end
     end
   end
 end
 
-require 'test/unit/runner/console'
-require 'test/unit/runner/emacs'
-require 'test/unit/runner/tap'
-require 'test/unit/runner/xml'
+require "test/unit/runner/console"
+require "test/unit/runner/emacs"
+require "test/unit/runner/xml"
