@@ -113,8 +113,21 @@ class TestChildContext < Test::Unit::TestCase
     assert_true(create_context.authenticated?)
   end
 
+  data(:hash_string => { "foo" => "bar", "baz" => 1, "true" => true },
+       :hash_symbol => { :foo => "bar", :baz => 1, :true => true },
+       :string => "string",
+       :fixnum => 42,
+       :true =>  true,
+       :false => false,)
+  def test_shelf(data)
+    @context.mail_transaction_shelf["key"] = data
+    assert_equal(data, @context.mail_transaction_shelf["key"])
+  end
+
   private
   def create_context
-    Milter::Manager::ChildContext.new(@clamav, @children, nil)
+    context = Milter::ClientContext.new
+    context.event_loop = @loop
+    Milter::Manager::ChildContext.new(@clamav, @children, context)
   end
 end
