@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2013  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -208,6 +208,9 @@ void             milter_logger_log_va_list    (MilterLogger        *logger,
                                                const gchar         *function,
                                                const gchar         *format,
                                                va_list              args);
+
+void             milter_logger_reopen         (MilterLogger        *logger);
+
 MilterLogLevelFlags
                  milter_logger_get_target_level
                                               (MilterLogger        *logger);
@@ -239,6 +242,11 @@ gboolean         milter_logger_set_target_item_by_string
                                                const gchar         *item_name,
                                                GError             **error);
 
+const gchar     *milter_logger_get_path       (MilterLogger        *logger);
+gboolean         milter_logger_set_path       (MilterLogger        *logger,
+                                               const gchar         *path,
+                                               GError             **error);
+
 void             milter_logger_connect_default_handler
                                               (MilterLogger        *logger);
 void             milter_logger_disconnect_default_handler
