@@ -41,6 +41,8 @@
 
 #include "../manager.h"
 
+static gpointer *stack_address = NULL;
+
 static gboolean initialized = FALSE;
 static MilterManager *the_manager = NULL;
 static gchar *option_config_dir = NULL;
@@ -74,6 +76,18 @@ static gboolean set_sigusr1_action = TRUE;
     }                                           \
 } G_STMT_END
 
+gpointer *
+milter_manager_get_stack_address (void)
+{
+    return stack_address;
+}
+
+void
+milter_manager_set_stack_address (gpointer *stack_address_)
+{
+    stack_address = stack_address_;
+}
+
 static gboolean
 print_version (const gchar *option_name, const gchar *value,
                gpointer data, GError **error)
@@ -134,7 +148,6 @@ milter_manager_init (int *argc, char ***argv)
     if (!g_option_context_parse(option_context, argc, argv, &error)) {
         g_print("%s\n", error->message);
 
-#if GLIB_CHECK_VERSION(2, 14, 0)
         if (g_error_matches(error,
                             G_OPTION_ERROR, G_OPTION_ERROR_UNKNOWN_OPTION)) {
             gchar *help;
@@ -142,7 +155,6 @@ milter_manager_init (int *argc, char ***argv)
             g_print("\n%s", help);
             g_free(help);
         }
-#endif
 
         g_error_free(error);
         g_option_context_free(option_context);
