@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2009-2011  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2009-2015  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -34,6 +34,7 @@ void test_socket_address (void);
 void test_n_processing_sessions (void);
 void test_packet_buffer_size (void);
 void test_quarantine_reason (void);
+void test_mail_transaction_shelf (void);
 
 static MilterClientContext *context;
 
@@ -167,6 +168,24 @@ test_quarantine_reason (void)
         milter_client_context_get_quarantine_reason(context));
 }
 
+void
+test_mail_transaction_shelf (void)
+{
+    cut_assert_equal_string(
+        NULL,
+        milter_client_context_get_mail_transaction_shelf_value(context, "test"));
+    milter_client_context_set_mail_transaction_shelf_value(context,
+                                                           "test",
+                                                           "test value");
+    cut_assert_equal_string(
+        "test value",
+        milter_client_context_get_mail_transaction_shelf_value(context, "test"));
+    milter_client_context_clear_mail_transaction_shelf(context);
+    cut_assert_equal_string(
+        NULL,
+        milter_client_context_get_mail_transaction_shelf_value(context, "test"));
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
