@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 #
-# Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
+# Copyright (C) 2008-2011  Kouhei Sutou <kou@clear-code.com>
 #
 # This library is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -261,7 +261,7 @@ class MilterTestClient
   def initialize_options
     @host = "127.0.0.1"
     @port = 9999
-    @print_ready = false
+    @print_status = false
     @timeout = 3
     @wait_second = 0
     @debug = false
@@ -401,11 +401,13 @@ class MilterTestClient
     when :header
       [:envelope_recipient_received, :data, :header].include?(@state)
     when :end_of_header
-      [:data, :header].include?(@state)
+      [:envelope_recipient_received, :data, :header].include?(@state)
     when :body
-      [:end_of_header, :body].include?(@state)
+      valid_states = [:envelope_recipient_received, :data, :end_of_header, :body]
+      valid_states.include?(@state)
     when :end_of_message
-      [:end_of_header, :body].include?(@state)
+      valid_states = [:envelope_recipient_received, :data, :end_of_header, :body]
+      valid_states.include?(@state)
     else
       info("unknown state: #{@state}")
       false
@@ -598,7 +600,7 @@ class MilterTestClient
 
   def resolve_flags(flags_class, flags)
     values = flags_class.values
-    flags.inject(0) do |result, flag|
+    flags.inject(flags_class.new) do |result, flag|
       flag_value = values.find {|value| value.nick == flag}
       if flag_value.nil?
         raise "unknown flag name for #{flags_class.name}: #{flag}"
