@@ -414,6 +414,7 @@ cut_setup (void)
     loop = milter_test_event_loop_new();
 
     context = milter_server_context_new();
+    milter_server_context_set_name(context, "test-server-context-signals");
     milter_agent_set_event_loop(MILTER_AGENT(context), loop);
     setup_signals(context);
 
@@ -577,6 +578,9 @@ pump_all_events (void)
 {
     GError *error;
 
+    if (MILTER_IS_LIBEV_EVENT_LOOP(loop))
+        cut_omit("MilterLibevEventLoop doesn't support GCutStringIOChannel.");
+
     milter_test_pump_all_events(loop);
     error = actual_error;
     actual_error = NULL;
@@ -1403,6 +1407,9 @@ test_write_error (void)
 {
     GError *error = NULL;
 
+    if (MILTER_IS_LIBEV_EVENT_LOOP(loop))
+        cut_omit("MilterLibevEventLoop doesn't support GCutStringIOChannel.");
+
     g_io_channel_set_buffered(write_channel, FALSE);
     g_io_channel_set_flags(write_channel, G_IO_FLAG_NONBLOCK, &error);
     gcut_assert_error(error);
