@@ -23,6 +23,7 @@ test_unit_dir = top + "binding" + "ruby" + "test-unit" + "lib"
 
 $LOAD_PATH.unshift(test_unit_dir.to_s)
 require 'test/unit'
+require 'test/unit/rr'
 
 $LOAD_PATH.unshift((top + "tool").to_s)
 
@@ -30,4 +31,5 @@ $LOAD_PATH.unshift(base.to_s)
 require 'tool-test-utils'
 
 ARGV.unshift("--priority-mode")
+ARGV.unshift("--max-diff-target-string-size=5000")
 exit Test::Unit::AutoRunner.run(true, base)
